uab.classes.ItemAction = uab.mixins.aceOO.Class(uab.classes.BaseAction)

function uab.classes.ItemAction.prototype:init(data)
	uab.classes.ItemAction.super.prototype.init(self)
	
	self.data = data
    self.text = self.data.name

	self:SetIcon()
end

function uab.classes.ItemAction.prototype:GetAttributes()
    local attribs = {}

    attribs["type"] = "item"
    attribs["item"] = self.text
    
    return attribs
end

function uab.classes.ItemAction.prototype:GetClassName()
	return "ItemAction"
end

function uab.classes.ItemAction.prototype:IsUsable()
    return IsUsableItem(self:GetText()) and not self:GetCooldown()
end

function uab.classes.ItemAction.prototype:GetCooldown()
    local start, duration, enable = GetItemCooldown(self.text)

    if start > 0 and duration > 0 and enable then
        return uab.classes.BaseAction.CalculateCooldown(start, duration)
    end
end

function uab.classes.ItemAction.prototype:GetCount()
    local bag, slot = self:FindItem()

    if bag and slot then
        local texture, itemCount, locked, quality, readable = GetContainerItemInfo(bag, slot)
        
        if itemCount then
            return itemCount
        else
            local _, _, _, _, _, _, _, maxstack, _, _ = GetItemInfo(self.text)
  
            if maxstack > 1 then
                return "0"
            end
        end
    end
end

function uab.classes.ItemAction.prototype:ShowTooltip(frame)
    --[[
    Need to find the referenced item.  Look in the player's inventory first.
    If not there, look in the player's bags.
    --]]

    GameTooltip:SetOwner(frame, "ANCHOR_RIGHT")
    GameTooltip:SetBackdropColor(0.1, 0.1, 0.1, 0.8)
    
    local bag, slot = self:FindItem()

    if bag and slot then
        GameTooltip:SetBagItem(bag,slot)
    elseif slot then
        GameTooltip:SetInventoryItem("player", slot)
    end
end

--[[---------------------------------------------------------------------------
Helper methods, to be used only by the class itself
-----------------------------------------------------------------------------]]

function uab.classes.ItemAction.prototype:SetIcon()
    self.icon = self.data.icon

    if not self.icon then
    	--[[
    	Need to find the referenced item.  Look in the player's inventory first.
        If not there, look in the player's bags.
    	--]]
    
        local bag, slot = self:FindItem()
    
        if bag and slot then
            self.icon = GetContainerItemInfo(bag,slot)
        elseif slot then
            self.icon = GetInventoryItemTexture("player",slot)
        else
            local _, _, _, _, _, _, _, _, _, texture = GetItemInfo(self.text)
    
            self.icon = texture
        end
    end        
    self.data.icon = self.icon
end

function uab.classes.ItemAction.prototype:FindItem()
    for bag=0,4 do
        for slot=1,GetContainerNumSlots(bag) do
            if GetContainerItemLink(bag,slot) then
                if string.find(GetContainerItemLink(bag,slot), self.text) then
                    return bag, slot
                end
            end
        end
    end
    
    for slot = 0, 19, 1 do
        if GetInventoryItemLink("player", slot) then
            if string.find(GetInventoryItemLink("player", slot), self.text) then
                return nil, slot
            end
        end
    end
end

